@@ -396,6 +396,16 @@ def parse_datasets(subparsers):
         dest='csv_display',
         action='store_true',
         help=Help.param_csv)
+    parser_datasets_list.add_argument(
+        '--max-size',
+        dest='max_size',
+        required=False,
+        help=Help.param_dataset_maxsize)
+    parser_datasets_list.add_argument(
+        '--min-size',
+        dest='min_size',
+        required=False,
+        help=Help.param_dataset_minsize)
     parser_datasets_list._action_groups.append(parser_datasets_list_optional)
     parser_datasets_list.set_defaults(func=api.dataset_list_cli)
 
@@ -597,6 +607,11 @@ def parse_datasets(subparsers):
         dest='dataset',
         required=False,
         help=argparse.SUPPRESS)
+    parser_datasets_metadata_optional.add_argument(
+        '--update',
+        dest='update',
+        action='store_true',
+        help=Help.param_dataset_metadata_update)
     parser_datasets_metadata_optional.add_argument(
         '-p', '--path', dest='path', help=Help.param_dataset_metadata_dir)
     parser_datasets_metadata._action_groups.append(
@@ -1015,9 +1030,7 @@ class Help(object):
     param_dataset_sort_by = (
         'Sort list results. Default is \'hottest\'. Valid options are '
         '\'hottest\', \'votes\', \'updated\', and \'active\'')
-    param_dataset_size = (
-        'Search for datasets of a specific size. Default is \'all\'. Valid '
-        'options are \'all\', \'small\', \'medium\', and \'large\'')
+    param_dataset_size = ('DEPRECATED. Please use --max-size and --min-size to filter dataset sizes.')
     param_dataset_file_type = (
         'Search for datasets with a specific file type. Default is \'all\'. '
         'Valid options are \'all\', \'csv\', \'sqlite\', \'json\', and '
@@ -1034,6 +1047,11 @@ class Help(object):
     param_dataset_metadata_dir = (
         'Location to download dataset metadata to. Defaults to current working '
         'directory')
+    param_dataset_metadata_update = (
+        'A flag to indicate whether the dataset'
+        'metadata should be updated.')
+    param_dataset_maxsize = 'Specify the maximum size of the dataset to return (bytes)'
+    param_dataset_minsize = 'Specify the minimum size of the dataset to return (bytes)'
 
     # Kernels params
     param_kernel = (
